[−][src]Struct fixed_hash::ApiDummy
Go here for an overview of the hash type API.
Methods
impl ApiDummy[src]
pub const fn repeat_byte(byte: u8) -> ApiDummy[src]
Returns a new fixed hash where all bits are set to the given byte.
pub const fn zero() -> ApiDummy[src]
Returns a new zero-initialized fixed hash.
pub const fn len_bytes() -> usize[src]
Returns the size of this hash in bytes.
pub fn as_bytes(&self) -> &[u8][src]
Extracts a byte slice containing the entire fixed hash.
pub fn as_bytes_mut(&mut self) -> &mut [u8][src]
Extracts a mutable byte slice containing the entire fixed hash.
pub const fn as_fixed_bytes(&self) -> &[u8; 32][src]
Extracts a reference to the byte array containing the entire fixed hash.
pub fn as_fixed_bytes_mut(&mut self) -> &mut [u8; 32][src]
Extracts a reference to the byte array containing the entire fixed hash.
pub const fn to_fixed_bytes(self) -> [u8; 32][src]
Returns the inner bytes array.
pub fn as_ptr(&self) -> *const u8[src]
Returns a constant raw pointer to the value.
pub fn as_mut_ptr(&mut self) -> *mut u8[src]
Returns a mutable raw pointer to the value.
pub fn assign_from_slice(&mut self, src: &[u8])[src]
Assign the bytes from the byte slice src to self.
Note
The given bytes are interpreted in big endian order.
Panics
If the length of src and the number of bytes in self do not match.
pub fn from_slice(src: &[u8]) -> Self[src]
Create a new fixed-hash from the given slice src.
Note
The given bytes are interpreted in big endian order.
Panics
If the length of src and the number of bytes in Self do not match.
pub fn covers(&self, b: &Self) -> bool[src]
Returns true if all bits set in b are also set in self.
pub fn is_zero(&self) -> bool[src]
Returns true if no bits are set.
impl ApiDummy[src]
Utilities using the byteorder crate.
pub fn to_low_u64_be(&self) -> u64[src]
Returns the lowest 8 bytes interpreted as big-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_le(&self) -> u64[src]
Returns the lowest 8 bytes interpreted as little-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn to_low_u64_ne(&self) -> u64[src]
Returns the lowest 8 bytes interpreted as native-endian.
Note
For hash type with less than 8 bytes the missing bytes are interpreted as being zero.
pub fn from_low_u64_be(val: u64) -> Self[src]
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as big endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_le(val: u64) -> Self[src]
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as little endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
pub fn from_low_u64_ne(val: u64) -> Self[src]
Creates a new hash type from the given u64 value.
Note
- The given
u64value is interpreted as native endian. - Ignores the most significant bits of the given value if the hash type has less than 8 bytes.
impl ApiDummy[src]
Utilities using the rand crate.
pub fn randomize_using<R: ?Sized>(&mut self, rng: &mut R) where
R: Rng, [src]
R: Rng,
Assign self to a cryptographically random value using the
given random number generator.
pub fn randomize(&mut self)[src]
Assign self to a cryptographically random value.
pub fn random_using<R: ?Sized>(rng: &mut R) -> Self where
R: Rng, [src]
R: Rng,
Create a new hash with cryptographically random content using the given random number generator.
pub fn random() -> Self[src]
Create a new hash with cryptographically random content.